package net.customware.license.support;

/**
 * Exemptors are checked prior to an actual license check being done. They are intended
 * to be used to check the system to see if a license is actually required.
 * 
 * @author David Peterson
 */
public interface Exemption {
    /**
     * This method is called to check if the current system is exempt from requiring a license.
     * The context object could be anything - applications can use it to provide other objects
     * or references when checking for exemptions.
     * 
     * @param context The application-specific context object.
     * @return <code>true</code> if the exemption applies in this context.
     */
    public boolean isExempt( Object context );
}
